#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_form.interfaces.form import IFormSecurityContext, IFormContextPermissionChecker

# import packages
from pyramid.decorator import reify


def get_edit_permission(request, context=None):
    """Get required edit permission"""
    if context is None:
        context = request.context
    registry = request.registry
    checker = registry.queryMultiAdapter((context, request), IFormContextPermissionChecker)
    if checker is None:
        checker = registry.queryAdapter(context, IFormContextPermissionChecker)
    if checker is not None:
        return checker.edit_permission


class ProtectedFormObjectMixin(object):
    """Form object protected by a permission"""

    @reify
    def permission(self):
        registry = self.request.registry
        checker = None
        context = IFormSecurityContext(self, None)
        if context is None:
            context = self.context
        view = getattr(self, '__parent__', None) or getattr(self, 'view', None) or getattr(self, 'table', None)
        if view is not None:
            checker = registry.queryMultiAdapter((context, self.request, view), IFormContextPermissionChecker)
        if checker is None:
            checker = registry.queryAdapter(context, IFormContextPermissionChecker)
        if checker is not None:
            return checker.edit_permission
