#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_form.interfaces.form import IFormViewletsManager, IFormPrefixViewletsManager, IWidgetsPrefixViewletsManager, \
    IWidgetsSuffixViewletsManager, IFormSuffixViewletsManager, IFormLayer, IFormHeaderViewletsManager, \
    IFormToolbarViewletsManager

# import packages
from pyams_template.template import template_config, get_view_template
from pyams_viewlet.manager import WeightOrderedViewletManager, viewletmanager_config
from zope.interface import implementer


@implementer(IFormViewletsManager)
class FormViewletManager(WeightOrderedViewletManager):
    """Base form viewlet manager"""


@viewletmanager_config(name='form_header', layer=IFormLayer)
@implementer(IFormHeaderViewletsManager)
class FormHeaderViewletManager(FormViewletManager):
    """Form header viewlet manager, display in modal's form dialog header"""


@viewletmanager_config(name='form_toolbar', layer=IFormLayer)
@template_config(template='templates/toolbar.pt', layer=IFormLayer)
@implementer(IFormToolbarViewletsManager)
class FormToolbarViewletsManager(FormViewletManager):
    """Form toolbar viewlet manager, displayed inside default form header"""

    template = get_view_template()


@viewletmanager_config(name='form_prefix', layer=IFormLayer)
@implementer(IFormPrefixViewletsManager)
class FormPrefixViewletManager(FormViewletManager):
    """Form prefix viewlet manager, displayed before form"""


@viewletmanager_config(name='widgets_prefix', layer=IFormLayer)
@implementer(IWidgetsPrefixViewletsManager)
class WidgetsPrefixViewletManager(FormViewletManager):
    """Form widgets prefix display manager, displayed before widgets"""


@viewletmanager_config(name='widgets_suffix', layer=IFormLayer)
@implementer(IWidgetsSuffixViewletsManager)
class WidgetsSuffixViewletManager(FormViewletManager):
    """Form widgets suffix viewlet manager, displayed after widgets"""


@viewletmanager_config(name='form_suffix', layer=IFormLayer)
@implementer(IFormSuffixViewletsManager)
class FormSuffixViewletManager(FormViewletManager):
    """Form suffix viewlet manager, displayed after form"""
